@@ -71,7 +71,7 @@ def id_probability(values, key=None, pos=None):
         # if val in all rows isn't unique, then it's not an id
         return 0
 
-    if key and key == 'id':
+    if key and str(key).lower() == 'id':
         prob += 0.5
 
     if pos and pos == 0:
@@ -179,6 +179,13 @@ def category_probability(values, key=None, pos=None):
             total_uncategorized += 1
 
 
+    # If this is a bunch of numbers, it's probably not a category
+    if all([is_a_int(v) or is_a_float(v) for v in values]) and \
+            len(all_matches) > math.sqrt(total_rows) / 2:
+
+        return 0 
+
+
     # If more than half the dataset isn't categorized based on this set of
     # labels, then it's probably not a category
 
@@ -193,7 +200,14 @@ def category_probability(values, key=None, pos=None):
         return 0
     else:
         tu = total_uncategorized if total_uncategorized > 0 else 1
+
         prob = float(total_categorized) / float(tu)
+        uncategorized_ratio = float(tu) / float(total_categorized)
+
+        print uncategorized_ratio
+        if uncategorized_ratio > .5:
+            return 0
+
         if prob >= 1:
             return 1
 
@@ -251,4 +265,4 @@ def detect_delimiter(values):
     if standard_deviation > 6:
         return None
 
-    return delimiter
+    return delimiter
\ No newline at end of file
