@@ -74,6 +74,9 @@ def is_a_int(value, key=None):
     if is_a_float(value):
         return False
 
+    if is_a_zip(value, key=key):
+        return False
+
     try:
         int(value)
         return True
@@ -212,18 +215,17 @@ def is_a_zip(value, key=None, pos=None):
     if key and key in ['zip', 'zipcode', 'postal code']:
         return True
 
-    if '-' in str(value):
-        if len(value) == 10:
-            return True
-
+    if str(value).count('-') == 1 and len(str(value)) == 10:
         primary = str(value).split('-')[0]
     else:
         primary = value
 
-    if not is_a_int(value):
+    try:
+        primary = int(primary)
+    except:
         return False
 
-    if len(str(value)) == 5 and int(value) > 499:
+    if len(str(primary)) == 5 and int(primary) > 499:
         return True
 
     return False
@@ -348,4 +350,3 @@ def is_a_url(value, key=None, pos=None):
         return False
 
     return len(m.group(0)) == len(value)
-
